==> crm-commom-vo-1.1.7.1.release.jar: com/biz/crm/nebular/sfa/visitdealer/resp/SfaVisitDealerMonthlyReportRespVo.java <==
package com.biz.crm.nebular.sfa.visitdealer.resp;

import com.biz.crm.nebular.mdm.CrmExtTenVo;
import com.bizunited.platform.saturn.engine.annotation.SaturnColumn;
import com.bizunited.platform.saturn.engine.annotation.SaturnEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * 经销商拜访月度报表;返回vo
 *
 * @author lf
 * @date 2020-11-20 11:21:59
 */
@Data
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@ApiModel(value = "经销商拜访月度报表;")
@SaturnEntity(name = "SfaVisitDealerMonthlyReportRespVo", description = "经销商拜访月度报表;")
public class SfaVisitDealerMonthlyReportRespVo extends CrmExtTenVo {
    @ApiModelProperty("人员账号;人员账号")
    @SaturnColumn(description = "人员账号;人员账号")
    private String visitUserName;

    @ApiModelProperty("人员姓名;人员姓名")
    @SaturnColumn(description = "人员姓名;人员姓名")
    private String visitRealName;

    @ApiModelProperty("人员职位编码;人员职位编码")
    @SaturnColumn(description = "人员职位编码;人员职位编码")
    private String visitPosCode;

    @ApiModelProperty("人员职位名称;人员职位名称")
    @SaturnColumn(description = "人员职位名称;人员职位名称")
    private String visitPosName;

    @ApiModelProperty("人员所属组织编码;人员所属组织编码")
    @SaturnColumn(description = "人员所属组织编码;人员所属组织编码")
    private String visitOrgCode;

    @ApiModelProperty("人员所属组织名称;人员所属组织名称")
    @SaturnColumn(description = "人员所属组织名称;人员所属组织名称")
    private String visitOrgName;

    @ApiModelProperty("拜访年;拜访年yyyy")
    @SaturnColumn(description = "拜访年;拜访年yyyy")
    private String visitYear;

    @ApiModelProperty("拜访月;拜访年MM")
    @SaturnColumn(description = "拜访月;拜访年MM")
    private String visitMonth;

    @ApiModelProperty("当月已拜访客户数量")
    @SaturnColumn(description = "当月已拜访客户数量")
    private String visitAlreadyNum;

    @ApiModelProperty("销售人员客户数量")
    @SaturnColumn(description = "销售人员客户数量")
    private String saleClientNum;

    @ApiModelProperty("当月拜访客户数量")
    @SaturnColumn(description = "当月拜访客户数量")
    private String visitClientNum;

    @ApiModelProperty("未拜访客户数量")
    @SaturnColumn(description = "未拜访客户数量")
    private String visitNotClientNum;

    @ApiModelProperty("客户拜访率")
    @SaturnColumn(description = "客户拜访率")
    private String visitClientProbability;

}

==> crm-commom-vo-1.1.9.30.release.jar: com/biz/crm/nebular/sfa/visitdealer/resp/SfaVisitDealerMonthlyReportRespVo.java <==
package com.biz.crm.nebular.sfa.visitdealer.resp;

import com.biz.crm.nebular.mdm.CrmExtTenVo;
import com.bizunited.platform.saturn.engine.annotation.SaturnColumn;
import com.bizunited.platform.saturn.engine.annotation.SaturnEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * 经销商拜访月度报表;返回vo
 *
 * @author lf
 * @date 2020-11-20 11:21:59
 */
@Data
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@ApiModel(value = "经销商拜访月度报表;")
@SaturnEntity(name = "SfaVisitDealerMonthlyReportRespVo", description = "经销商拜访月度报表;")
public class SfaVisitDealerMonthlyReportRespVo extends CrmExtTenVo {
    @ApiModelProperty("人员账号;人员账号")
    @SaturnColumn(description = "人员账号;人员账号")
    private String visitUserName;

    @ApiModelProperty("人员姓名;人员姓名")
    @SaturnColumn(description = "人员姓名;人员姓名")
    private String visitRealName;

    @ApiModelProperty("人员职位编码;人员职位编码")
    @SaturnColumn(description = "人员职位编码;人员职位编码")
    private String visitPosCode;

    @ApiModelProperty("人员职位名称;人员职位名称")
    @SaturnColumn(description = "人员职位名称;人员职位名称")
    private String visitPosName;

    @ApiModelProperty("人员所属组织编码;人员所属组织编码")
    @SaturnColumn(description = "人员所属组织编码;人员所属组织编码")
    private String visitOrgCode;

    @ApiModelProperty("人员所属组织名称;人员所属组织名称")
    @SaturnColumn(description = "人员所属组织名称;人员所属组织名称")
    private String visitOrgName;

    @ApiModelProperty("人员上级所属组织编码;人员上级所属组织编码")
    private String visitParentOrgCode;

    @ApiModelProperty("人员上级所属组织名称;人员上级所属组织名称")
    private String visitParentOrgName;

    @ApiModelProperty("拜访年;拜访年yyyy")
    @SaturnColumn(description = "拜访年;拜访年yyyy")
    private String visitYear;

    @ApiModelProperty("拜访月;拜访年MM")
    @SaturnColumn(description = "拜访月;拜访年MM")
    private String visitMonth;

    @ApiModelProperty("当月已拜访客户数量")
    @SaturnColumn(description = "当月已拜访客户数量")
    private String visitAlreadyNum;

    @ApiModelProperty("销售人员客户数量")
    @SaturnColumn(description = "销售人员客户数量")
    private String saleClientNum;

    @ApiModelProperty("当月拜访客户数量")
    @SaturnColumn(description = "当月拜访客户数量")
    private String visitClientNum;

    @ApiModelProperty("未拜访客户数量")
    @SaturnColumn(description = "未拜访客户数量")
    private String visitNotClientNum;

    @ApiModelProperty("客户拜访率")
    @SaturnColumn(description = "客户拜访率")
    private String visitClientProbability;

}
